@@ -94,6 +94,7 @@ class AnalyzeIamPolicyLongrunningMetadata(proto.Message):
 
 class ExportAssetsRequest(proto.Message):
     r"""Export asset request.
+
     Attributes:
         parent (str):
             Required. The relative name of the root
@@ -196,6 +197,7 @@ class ExportAssetsResponse(proto.Message):
 
 class ListAssetsRequest(proto.Message):
     r"""ListAssets request.
+
     Attributes:
         parent (str):
             Required. Name of the organization or project the assets
@@ -278,6 +280,7 @@ class ListAssetsRequest(proto.Message):
 
 class ListAssetsResponse(proto.Message):
     r"""ListAssets response.
+
     Attributes:
         read_time (google.protobuf.timestamp_pb2.Timestamp):
             Time the snapshot was taken.
@@ -301,6 +304,7 @@ class ListAssetsResponse(proto.Message):
 
 class BatchGetAssetsHistoryRequest(proto.Message):
     r"""Batch get assets history request.
+
     Attributes:
         parent (str):
             Required. The relative name of the root
@@ -358,6 +362,7 @@ class BatchGetAssetsHistoryRequest(proto.Message):
 
 class BatchGetAssetsHistoryResponse(proto.Message):
     r"""Batch get assets history response.
+
     Attributes:
         assets (Sequence[google.cloud.asset_v1.types.TemporalAsset]):
             A list of assets with valid time windows.
@@ -370,6 +375,7 @@ class BatchGetAssetsHistoryResponse(proto.Message):
 
 class CreateFeedRequest(proto.Message):
     r"""Create asset feed request.
+
     Attributes:
         parent (str):
             Required. The name of the
@@ -399,6 +405,7 @@ class CreateFeedRequest(proto.Message):
 
 class GetFeedRequest(proto.Message):
     r"""Get asset feed request.
+
     Attributes:
         name (str):
             Required. The name of the Feed and it must be in the format
@@ -412,6 +419,7 @@ class GetFeedRequest(proto.Message):
 
 class ListFeedsRequest(proto.Message):
     r"""List asset feeds request.
+
     Attributes:
         parent (str):
             Required. The parent
@@ -427,6 +435,7 @@ class ListFeedsRequest(proto.Message):
 
 class ListFeedsResponse(proto.Message):
     r"""
+
     Attributes:
         feeds (Sequence[google.cloud.asset_v1.types.Feed]):
             A list of feeds.
@@ -437,6 +446,7 @@ class ListFeedsResponse(proto.Message):
 
 class UpdateFeedRequest(proto.Message):
     r"""Update asset feed request.
+
     Attributes:
         feed (google.cloud.asset_v1.types.Feed):
             Required. The new values of feed details. It must match an
@@ -458,6 +468,7 @@ class UpdateFeedRequest(proto.Message):
 
 class DeleteFeedRequest(proto.Message):
     r"""
+
     Attributes:
         name (str):
             Required. The name of the feed and it must be in the format
@@ -471,13 +482,23 @@ class DeleteFeedRequest(proto.Message):
 
 class OutputConfig(proto.Message):
     r"""Output configuration for export assets destination.
+
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         gcs_destination (google.cloud.asset_v1.types.GcsDestination):
             Destination on Cloud Storage.
+            This field is a member of `oneof`_ ``destination``.
         bigquery_destination (google.cloud.asset_v1.types.BigQueryDestination):
             Destination on BigQuery. The output table
             stores the fields in asset proto as columns in
             BigQuery.
+            This field is a member of `oneof`_ ``destination``.
     """
 
     gcs_destination = proto.Field(
@@ -490,9 +511,13 @@ class OutputConfig(proto.Message):
 
 class OutputResult(proto.Message):
     r"""Output result of export assets.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         gcs_result (google.cloud.asset_v1.types.GcsOutputResult):
             Export result on Cloud Storage.
+            This field is a member of `oneof`_ ``result``.
     """
 
     gcs_result = proto.Field(
@@ -502,6 +527,7 @@ class OutputResult(proto.Message):
 
 class GcsOutputResult(proto.Message):
     r"""A Cloud Storage output result.
+
     Attributes:
         uris (Sequence[str]):
             List of uris of the Cloud Storage objects. Example:
@@ -513,6 +539,14 @@ class GcsOutputResult(proto.Message):
 
 class GcsDestination(proto.Message):
     r"""A Cloud Storage location.
+
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         uri (str):
             The uri of the Cloud Storage object. It's the same uri that
@@ -525,6 +559,7 @@ class GcsDestination(proto.Message):
             there is no
             `hold <https://cloud.google.com/storage/docs/object-holds>`__,
             it will be overwritten with the exported result.
+            This field is a member of `oneof`_ ``object_uri``.
         uri_prefix (str):
             The uri prefix of all generated Cloud Storage objects.
             Example: "gs://bucket_name/object_name_prefix". Each object
@@ -535,6 +570,7 @@ class GcsDestination(proto.Message):
             compute.googleapis.com/Disk assets. An INVALID_ARGUMENT
             error will be returned if file with the same name
             "gs://bucket_name/object_name_prefix" already exists.
+            This field is a member of `oneof`_ ``object_uri``.
     """
 
     uri = proto.Field(proto.STRING, number=1, oneof="object_uri",)
@@ -543,6 +579,7 @@ class GcsDestination(proto.Message):
 
 class BigQueryDestination(proto.Message):
     r"""A BigQuery destination for exporting assets to.
+
     Attributes:
         dataset (str):
             Required. The BigQuery dataset in format
@@ -651,6 +688,7 @@ class PartitionSpec(proto.Message):
 
 class PubsubDestination(proto.Message):
     r"""A Pub/Sub destination.
+
     Attributes:
         topic (str):
             The name of the Pub/Sub topic to publish to. Example:
@@ -662,9 +700,13 @@ class PubsubDestination(proto.Message):
 
 class FeedOutputConfig(proto.Message):
     r"""Output configuration for asset feed destination.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         pubsub_destination (google.cloud.asset_v1.types.PubsubDestination):
             Destination on Pub/Sub.
+            This field is a member of `oneof`_ ``destination``.
     """
 
     pubsub_destination = proto.Field(
@@ -765,6 +807,7 @@ class Feed(proto.Message):
 
 class SearchAllResourcesRequest(proto.Message):
     r"""Search all resources request.
+
     Attributes:
         scope (str):
             Required. A scope can be a project, a folder, or an
@@ -925,6 +968,7 @@ class SearchAllResourcesRequest(proto.Message):
 
 class SearchAllResourcesResponse(proto.Message):
     r"""Search all resources response.
+
     Attributes:
         results (Sequence[google.cloud.asset_v1.types.ResourceSearchResult]):
             A list of Resources that match the search
@@ -949,6 +993,7 @@ class SearchAllResourcesResponse(proto.Message):
 
 class SearchAllIamPoliciesRequest(proto.Message):
     r"""Search all IAM policies request.
+
     Attributes:
         scope (str):
             Required. A scope can be a project, a folder, or an
@@ -1069,6 +1114,7 @@ class SearchAllIamPoliciesRequest(proto.Message):
 
 class SearchAllIamPoliciesResponse(proto.Message):
     r"""Search all IAM policies response.
+
     Attributes:
         results (Sequence[google.cloud.asset_v1.types.IamPolicySearchResult]):
             A list of IamPolicy that match the search
@@ -1093,6 +1139,7 @@ class SearchAllIamPoliciesResponse(proto.Message):
 
 class IamPolicyAnalysisQuery(proto.Message):
     r"""## IAM policy analysis query message.
+
     Attributes:
         scope (str):
             Required. The relative name of the root asset. Only
@@ -1181,6 +1228,7 @@ class IamPolicyAnalysisQuery(proto.Message):
 
     class Options(proto.Message):
         r"""Contains query options.
+
         Attributes:
             expand_groups (bool):
                 Optional. If true, the identities section of the result will
@@ -1279,12 +1327,16 @@ class IamPolicyAnalysisQuery(proto.Message):
 
     class ConditionContext(proto.Message):
         r"""The IAM conditions context.
+
+        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
         Attributes:
             access_time (google.protobuf.timestamp_pb2.Timestamp):
                 The hypothetical access timestamp to evaluate IAM
                 conditions. Note that this value must not be earlier than
                 the current time; otherwise, an INVALID_ARGUMENT error will
                 be returned.
+                This field is a member of `oneof`_ ``TimeContext``.
         """
 
         access_time = proto.Field(
@@ -1354,6 +1406,7 @@ class AnalyzeIamPolicyResponse(proto.Message):
 
     class IamPolicyAnalysis(proto.Message):
         r"""An analysis message to group the query and results.
+
         Attributes:
             analysis_query (google.cloud.asset_v1.types.IamPolicyAnalysisQuery):
                 The analysis query.
@@ -1393,15 +1446,25 @@ class IamPolicyAnalysisOutputConfig(proto.Message):
     r"""Output configuration for export IAM policy analysis
     destination.
 
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         gcs_destination (google.cloud.asset_v1.types.IamPolicyAnalysisOutputConfig.GcsDestination):
             Destination on Cloud Storage.
+            This field is a member of `oneof`_ ``destination``.
         bigquery_destination (google.cloud.asset_v1.types.IamPolicyAnalysisOutputConfig.BigQueryDestination):
             Destination on BigQuery.
+            This field is a member of `oneof`_ ``destination``.
     """
 
     class GcsDestination(proto.Message):
         r"""A Cloud Storage location.
+
         Attributes:
             uri (str):
                 Required. The uri of the Cloud Storage object. It's the same
@@ -1421,6 +1484,7 @@ class IamPolicyAnalysisOutputConfig(proto.Message):
 
     class BigQueryDestination(proto.Message):
         r"""A BigQuery destination.
+
         Attributes:
             dataset (str):
                 Required. The BigQuery dataset in format
@@ -1512,11 +1576,13 @@ class AnalyzeIamPolicyLongrunningRequest(proto.Message):
 class AnalyzeIamPolicyLongrunningResponse(proto.Message):
     r"""A response message for
     [AssetService.AnalyzeIamPolicyLongrunning][google.cloud.asset.v1.AssetService.AnalyzeIamPolicyLongrunning].
-        """
+
+    """
 
 
 class AnalyzeMoveRequest(proto.Message):
     r"""The request message for performing resource move analysis.
+
     Attributes:
         resource (str):
             Required. Name of the resource to perform the
@@ -1552,6 +1618,7 @@ class AnalyzeMoveRequest(proto.Message):
 
 class AnalyzeMoveResponse(proto.Message):
     r"""The response message for resource move analysis.
+
     Attributes:
         move_analysis (Sequence[google.cloud.asset_v1.types.MoveAnalysis]):
             The list of analyses returned from performing
@@ -1566,6 +1633,14 @@ class AnalyzeMoveResponse(proto.Message):
 
 class MoveAnalysis(proto.Message):
     r"""A message to group the analysis information.
+
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         display_name (str):
             The user friendly display name of the
@@ -1573,9 +1648,11 @@ class MoveAnalysis(proto.Message):
         analysis (google.cloud.asset_v1.types.MoveAnalysisResult):
             Analysis result of moving the target
             resource.
+            This field is a member of `oneof`_ ``result``.
         error (google.rpc.status_pb2.Status):
             Description of error encountered when
             performing the analysis.
+            This field is a member of `oneof`_ ``result``.
     """
 
     display_name = proto.Field(proto.STRING, number=1,)
@@ -1589,6 +1666,7 @@ class MoveAnalysis(proto.Message):
 
 class MoveAnalysisResult(proto.Message):
     r"""An analysis result including blockers and warnings.
+
     Attributes:
         blockers (Sequence[google.cloud.asset_v1.types.MoveImpact]):
             Blocking information that would prevent the
@@ -1608,6 +1686,7 @@ class MoveAnalysisResult(proto.Message):
 
 class MoveImpact(proto.Message):
     r"""A message to group impacts of moving the target resource.
+
     Attributes:
         detail (str):
             User friendly impact detail in a free form
