@@ -87,6 +87,7 @@ class TemporalAsset(proto.Message):
 
 class TimeWindow(proto.Message):
     r"""A time window specified by its ``start_time`` and ``end_time``.
+
     Attributes:
         start_time (google.protobuf.timestamp_pb2.Timestamp):
             Start time of the time window (exclusive).
@@ -111,6 +112,13 @@ class Asset(proto.Message):
     types <https://cloud.google.com/asset-inventory/docs/supported-asset-types>`__
     for more information.
 
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         update_time (google.protobuf.timestamp_pb2.Timestamp):
             The last update timestamp of an asset. update_time is
@@ -151,12 +159,15 @@ class Asset(proto.Message):
         access_policy (google.identity.accesscontextmanager.v1.access_policy_pb2.AccessPolicy):
             Please also refer to the `access policy user
             guide <https://cloud.google.com/access-context-manager/docs/overview#access-policies>`__.
+            This field is a member of `oneof`_ ``access_context_policy``.
         access_level (google.identity.accesscontextmanager.v1.access_level_pb2.AccessLevel):
             Please also refer to the `access level user
             guide <https://cloud.google.com/access-context-manager/docs/overview#access-levels>`__.
+            This field is a member of `oneof`_ ``access_context_policy``.
         service_perimeter (google.identity.accesscontextmanager.v1.service_perimeter_pb2.ServicePerimeter):
             Please also refer to the `service perimeter user
             guide <https://cloud.google.com/vpc-service-controls/docs/overview>`__.
+            This field is a member of `oneof`_ ``access_context_policy``.
         os_inventory (google.cloud.osconfig_v1.Inventory):
             A representation of runtime OS Inventory information. See
             `this
@@ -214,6 +225,7 @@ class Asset(proto.Message):
 
 class Resource(proto.Message):
     r"""A representation of a Google Cloud resource.
+
     Attributes:
         version (str):
             The API version. Example: ``v1``
@@ -271,6 +283,7 @@ class Resource(proto.Message):
 
 class RelatedAssets(proto.Message):
     r"""The detailed related assets with the ``relationship_type``.
+
     Attributes:
         relationship_attributes (google.cloud.asset_v1.types.RelationshipAttributes):
             The detailed relationship attributes.
@@ -690,6 +703,7 @@ class AttachedResource(proto.Message):
 
 class RelatedResources(proto.Message):
     r"""The related resources of the primary resource.
+
     Attributes:
         related_resources (Sequence[google.cloud.asset_v1.types.RelatedResource]):
             The detailed related resources of the primary
@@ -703,6 +717,7 @@ class RelatedResources(proto.Message):
 
 class RelatedResource(proto.Message):
     r"""The detailed related resource.
+
     Attributes:
         asset_type (str):
             The type of the asset. Example:
@@ -800,6 +815,7 @@ class IamPolicySearchResult(proto.Message):
 
     class Explanation(proto.Message):
         r"""Explanation about the IAM policy search result.
+
         Attributes:
             matched_permissions (Sequence[google.cloud.asset_v1.types.IamPolicySearchResult.Explanation.MatchedPermissionsEntry]):
                 The map from roles to their included permissions that match
@@ -816,6 +832,7 @@ class IamPolicySearchResult(proto.Message):
 
         class Permissions(proto.Message):
             r"""IAM permissions
+
             Attributes:
                 permissions (Sequence[str]):
                     A list of permissions. A sample permission string:
@@ -866,6 +883,7 @@ class IamPolicyAnalysisState(proto.Message):
 
 class ConditionEvaluation(proto.Message):
     r"""The Condition evaluation.
+
     Attributes:
         evaluation_value (google.cloud.asset_v1.types.ConditionEvaluation.EvaluationValue):
             The evaluation result.
@@ -912,6 +930,7 @@ class IamPolicyAnalysisResult(proto.Message):
 
     class Resource(proto.Message):
         r"""A Google Cloud resource under analysis.
+
         Attributes:
             full_resource_name (str):
                 The `full resource
@@ -927,11 +946,21 @@ class IamPolicyAnalysisResult(proto.Message):
 
     class Access(proto.Message):
         r"""An IAM role or permission under analysis.
+
+        This message has `oneof`_ fields (mutually exclusive fields).
+        For each oneof, at most one member field can be set at the same time.
+        Setting any member of the oneof automatically clears all other
+        members.
+
+        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
         Attributes:
             role (str):
                 The role.
+                This field is a member of `oneof`_ ``oneof_access``.
             permission (str):
                 The permission.
+                This field is a member of `oneof`_ ``oneof_access``.
             analysis_state (google.cloud.asset_v1.types.IamPolicyAnalysisState):
                 The analysis state of this access.
         """
@@ -944,6 +973,7 @@ class IamPolicyAnalysisResult(proto.Message):
 
     class Identity(proto.Message):
         r"""An identity under analysis.
+
         Attributes:
             name (str):
                 The identity name in any form of members appear in `IAM
@@ -969,6 +999,7 @@ class IamPolicyAnalysisResult(proto.Message):
 
     class Edge(proto.Message):
         r"""A directional edge.
+
         Attributes:
             source_node (str):
                 The source node of the edge. For example, it
@@ -1046,6 +1077,7 @@ class IamPolicyAnalysisResult(proto.Message):
 
     class IdentityList(proto.Message):
         r"""The identities and group edges.
+
         Attributes:
             identities (Sequence[google.cloud.asset_v1.types.IamPolicyAnalysisResult.Identity]):
                 Only the identities that match one of the following
