@@ -46,6 +46,7 @@ class ContentType(proto.Enum):
 
 class CreateFeedRequest(proto.Message):
     r"""Create asset feed request.
+
     Attributes:
         parent (str):
             Required. The name of the
@@ -75,6 +76,7 @@ class CreateFeedRequest(proto.Message):
 
 class GetFeedRequest(proto.Message):
     r"""Get asset feed request.
+
     Attributes:
         name (str):
             Required. The name of the Feed and it must be in the format
@@ -88,6 +90,7 @@ class GetFeedRequest(proto.Message):
 
 class ListFeedsRequest(proto.Message):
     r"""List asset feeds request.
+
     Attributes:
         parent (str):
             Required. The parent
@@ -103,6 +106,7 @@ class ListFeedsRequest(proto.Message):
 
 class ListFeedsResponse(proto.Message):
     r"""
+
     Attributes:
         feeds (Sequence[google.cloud.asset_v1p2beta1.types.Feed]):
             A list of feeds.
@@ -113,6 +117,7 @@ class ListFeedsResponse(proto.Message):
 
 class UpdateFeedRequest(proto.Message):
     r"""Update asset feed request.
+
     Attributes:
         feed (google.cloud.asset_v1p2beta1.types.Feed):
             Required. The new values of feed details. It must match an
@@ -134,6 +139,7 @@ class UpdateFeedRequest(proto.Message):
 
 class DeleteFeedRequest(proto.Message):
     r"""
+
     Attributes:
         name (str):
             Required. The name of the feed and it must be in the format
@@ -147,9 +153,13 @@ class DeleteFeedRequest(proto.Message):
 
 class OutputConfig(proto.Message):
     r"""Output configuration for export assets destination.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         gcs_destination (google.cloud.asset_v1p2beta1.types.GcsDestination):
             Destination on Cloud Storage.
+            This field is a member of `oneof`_ ``destination``.
     """
 
     gcs_destination = proto.Field(
@@ -159,6 +169,9 @@ class OutputConfig(proto.Message):
 
 class GcsDestination(proto.Message):
     r"""A Cloud Storage location.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         uri (str):
             The uri of the Cloud Storage object. It's the same uri that
@@ -167,6 +180,7 @@ class GcsDestination(proto.Message):
             Object
             Metadata <https://cloud.google.com/storage/docs/viewing-editing-metadata>`__
             for more information.
+            This field is a member of `oneof`_ ``object_uri``.
     """
 
     uri = proto.Field(proto.STRING, number=1, oneof="object_uri",)
@@ -174,6 +188,7 @@ class GcsDestination(proto.Message):
 
 class PubsubDestination(proto.Message):
     r"""A Cloud Pubsub destination.
+
     Attributes:
         topic (str):
             The name of the Cloud Pub/Sub topic to publish to. For
@@ -185,9 +200,13 @@ class PubsubDestination(proto.Message):
 
 class FeedOutputConfig(proto.Message):
     r"""Output configuration for asset feed destination.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         pubsub_destination (google.cloud.asset_v1p2beta1.types.PubsubDestination):
             Destination on Cloud Pubsub.
+            This field is a member of `oneof`_ ``destination``.
     """
 
     pubsub_destination = proto.Field(
