@@ -112,7 +112,7 @@ class AssetServiceGrpcTransport(AssetServiceTransport):
         self._grpc_channel = None
         self._ssl_channel_credentials = ssl_channel_credentials
         self._stubs: Dict[str, Callable] = {}
-        self._operations_client = None
+        self._operations_client: Optional[operations_v1.OperationsClient] = None
 
         if api_mtls_endpoint:
             warnings.warn("api_mtls_endpoint is deprecated", DeprecationWarning)
@@ -305,5 +305,8 @@ class AssetServiceGrpcTransport(AssetServiceTransport):
             )
         return self._stubs["export_iam_policy_analysis"]
 
+    def close(self):
+        self.grpc_channel.close()
+
 
 __all__ = ("AssetServiceGrpcTransport",)
