@@ -34,6 +34,7 @@ __protobuf__ = proto.module(
 
 class IamPolicyAnalysisQuery(proto.Message):
     r"""IAM policy analysis query message.
+
     Attributes:
         parent (str):
             Required. The relative name of the root
@@ -122,6 +123,7 @@ class AnalyzeIamPolicyRequest(proto.Message):
 
     class Options(proto.Message):
         r"""Contains request options.
+
         Attributes:
             expand_groups (bool):
                 Optional. If true, the identities section of the result will
@@ -248,6 +250,7 @@ class AnalyzeIamPolicyResponse(proto.Message):
 
     class IamPolicyAnalysis(proto.Message):
         r"""An analysis message to group the query and results.
+
         Attributes:
             analysis_query (google.cloud.asset_v1p4beta1.types.IamPolicyAnalysisQuery):
                 The analysis query.
@@ -284,13 +287,18 @@ class IamPolicyAnalysisOutputConfig(proto.Message):
     r"""Output configuration for export IAM policy analysis
     destination.
 
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         gcs_destination (google.cloud.asset_v1p4beta1.types.IamPolicyAnalysisOutputConfig.GcsDestination):
             Destination on Cloud Storage.
+            This field is a member of `oneof`_ ``destination``.
     """
 
     class GcsDestination(proto.Message):
         r"""A Cloud Storage location.
+
         Attributes:
             uri (str):
                 Required. The uri of the Cloud Storage object. It's the same
@@ -324,6 +332,7 @@ class ExportIamPolicyAnalysisRequest(proto.Message):
 
     class Options(proto.Message):
         r"""Contains request options.
+
         Attributes:
             expand_groups (bool):
                 Optional. If true, the identities section of the result will
