@@ -19,13 +19,15 @@ import re
 from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
+from google.api_core.client_options import ClientOptions  # type: ignore
 from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.cloud.asset_v1p5beta1.services.asset_service import pagers
 from google.cloud.asset_v1p5beta1.types import asset_service
 from google.cloud.asset_v1p5beta1.types import assets
@@ -168,9 +170,9 @@ class AssetServiceAsyncClient:
 
     async def list_assets(
         self,
-        request: asset_service.ListAssetsRequest = None,
+        request: Union[asset_service.ListAssetsRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListAssetsAsyncPager:
@@ -178,7 +180,7 @@ class AssetServiceAsyncClient:
         paged results in response.
 
         Args:
-            request (:class:`google.cloud.asset_v1p5beta1.types.ListAssetsRequest`):
+            request (Union[google.cloud.asset_v1p5beta1.types.ListAssetsRequest, dict]):
                 The request object. ListAssets request.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -233,6 +235,12 @@ class AssetServiceAsyncClient:
         # Done; return the response.
         return response
 
+    async def __aenter__(self):
+        return self
+
+    async def __aexit__(self, exc_type, exc, tb):
+        await self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
