@@ -20,7 +20,6 @@ from google.api_core import gapic_v1  # type: ignore
 from google.api_core import grpc_helpers_async  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-import packaging.version
 
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
@@ -257,5 +256,8 @@ class AssetServiceGrpcAsyncIOTransport(AssetServiceTransport):
             )
         return self._stubs["list_assets"]
 
+    def close(self):
+        return self.grpc_channel.close()
+
 
 __all__ = ("AssetServiceGrpcAsyncIOTransport",)
